function [tosave] = Hamiltonian(params,data,forces)
%Here we import the parameters from the structure
qmat = data.qmat;
dim = params.ham.dim;
numBasis = params.ham.numBasis;
hamTotal = 0*qmat{1};
disp(['The size of the Hamiltonian is ', num2str(size(hamTotal,1))])

%Some Error Checking
if params.ham.nonuniformbasis
    numBasis = max(params.ham.excitations);
end

if min(size(forces.second)) == 1;
    forces.second = diag(forces.second);
end

%Display the modes to diagonalize
disp(['Modes are: ', num2str(params.ham.truemodes)]);

% Second-Order Terms
for n = 1:size(params.ham.twomodeComb,1);
    p1 = params.ham.twomodeComb(n,1);
    p2 = params.ham.twomodeComb(n,2);
    secondforce = forces.second(p1,p2);
    [rte,in1]=min(abs(params.ham.truemodes-p1));
    [rte,in2]=min(abs(params.ham.truemodes-p2));
    
    disp(['Second Order:  ', num2str(params.ham.twomodeComb(n,:)), ' Modes: ', num2str(in1), num2str(in2), ' Force: ', num2str(secondforce,'%5.2f')]);
    hamTotal = hamTotal + (secondforce/2)*((qmat{in1})*(qmat{in2}));
    
    %Add momentum matrix for diagonal second order force constants
    if in1==in2
        hamTotal = hamTotal + (secondforce/2)*(data.pmat{in1}^2);
    end
end

%Third-Order Terms
for n =1:size(params.ham.thirdOrderCombs,1)
    p1 = params.ham.thirdOrderCombs(n,1);
    p2 = params.ham.thirdOrderCombs(n,2);
    p3 = params.ham.thirdOrderCombs(n,3);
    thirdforce = forces.third(p1,p2,p3);
    [rte,in1]=min(abs(params.ham.truemodes-p1));
    [rte,in2]=min(abs(params.ham.truemodes-p2));
    [rte,in3]=min(abs(params.ham.truemodes-p3));
    
    disp(['Third Order:  ', num2str(params.ham.thirdOrderCombs(n,:)), ' Modes: ', num2str(in1), num2str(in2), num2str(in3), ' Force: ', num2str(thirdforce,'%5.2f')]);
    hamTotal = hamTotal + (1/6)*(thirdforce)*(qmat{in1}*qmat{in2}*qmat{in3});
end

%Fourth-Order Semi-diagonal Terms
for n =1:size(params.ham.fourthOrdercombinations,1)

    p1 = params.ham.fourthOrdercombinations(n,1);
    p2 = params.ham.fourthOrdercombinations(n,2);
    p3 = params.ham.fourthOrdercombinations(n,3);
    fourthforce = forces.fourth(p1,p2,p3);
    [rte,in1]=min(abs(params.ham.truemodes-p1));
    [rte,in2]=min(abs(params.ham.truemodes-p2));
    [rte,in3]=min(abs(params.ham.truemodes-p3));

    disp(['Fourth Order: ', num2str(params.ham.fourthOrdercombinations(n,:)), ' Modes: ', num2str(in1), num2str(in2), num2str(in3), ' Force: ', num2str(fourthforce,'%5.2f')]);
    hamTotal = hamTotal + (1/24)*(fourthforce)*(qmat{in1}*qmat{in2}*qmat{in3}^2);
end


%Here is where the Diagonalization happens
[evects, evalsUnsort] = eigs(hamTotal,params.ham.numvectIterate,'sr');

%Sort the eigenvalues from smallest to larges
[evalsSort,order] = sort(diag(evalsUnsort));
diagevalsUnsorted = diag(evalsUnsort);
evectsSort = sortEvects(evects,order);
% %end
%Subtract the zero-point to get transition frequencies
tosave.evalsSort = evalsSort-evalsSort(1);

%Output these variables
tosave.basis = data.basis;
tosave.evects = evectsSort;
tosave.evals = evalsSort;
