%%THIS FUCNTION READS IN A GAUSSIAN INPUT FILE AND EXTRACTS THE FORCE
%%CONSTANTS
%%C. Baiz - June 2009


function [forces] = ReadGaussianInput(filename)


if ~exist(filename,'file')
    disp('Error: Input file does not exist. Please check your path')
    molecule_line = 0;
    contents =0;
else
    %Read Contents of the input and parse to find the matching lines
    contents = textread(filename,'%s', 'whitespace','\n');
    Harmonicfreq_lines = strmatch('Frequencies --', contents);
    ThirdDeriv_lines = strmatch('Third  Der.', contents);
    FourthDeriv_lines = strmatch('Fourth Der.', contents);


%Read the Harmonic Frequencies
disp('Reading second-order force constants');
disp(['There are ' num2str(3*numel(Harmonicfreq_lines)) ' vibrational modes']);

for n= 1:numel(Harmonicfreq_lines) 
    tempStr = strread(contents{Harmonicfreq_lines(n)},'%s');
    tempFreq(n,1) = str2double(tempStr{3});
    tempFreq(n,2) = str2double(tempStr{4});
    tempFreq(n,3) = str2double(tempStr{5});
end
HarmonicFrequencies = reshape(tempFreq',[],1);
Forces.Second = HarmonicFrequencies;

%Read the third Order Force Constants
disp('Reading third-order force constants');
disp(['There are ' num2str(numel(ThirdDeriv_lines)) ' third-order force constants']);

Third(numel(3*numel(Harmonicfreq_lines)), numel(3*numel(Harmonicfreq_lines)),numel(3*numel(Harmonicfreq_lines))) = 0;
for n= 1:numel(ThirdDeriv_lines)
    tempStr = strread(contents{ThirdDeriv_lines(n)},'%s');
    Third(str2double(tempStr{5}),str2double(tempStr{4}),str2double(tempStr{3})) = str2double(tempStr{6});
end
Forces.Third = Third;

%Read the fourth Order Force Constants
disp('Reading fourth-order force constants');
disp(['There are ' num2str(numel(FourthDeriv_lines)) ' third-order force constants']);

Fourth(numel(3*numel(Harmonicfreq_lines)), numel(3*numel(Harmonicfreq_lines)),numel(3*numel(Harmonicfreq_lines))) = 0;
for n= 1:numel(FourthDeriv_lines)
    tempStr = strread(contents{FourthDeriv_lines(n)},'%s');
    Fourth(str2double(tempStr{6}),str2double(tempStr{5}),str2double(tempStr{4})) = str2double(tempStr{7});
end
Forces.Fourth = Fourth;

end
