function forces = errorCheck(params,forces)

if ~isfield(forces,'second')
    error('Second-order Force constants not set. Please check forces.second')
end


if max(params.ham.mode) > size(forces.second)
    error('The mode selected in params.ham.mode is not in the force constants. See the documentation')
end

if ~isfield(forces,'third')
    disp('Warning: Third-order Force constants not set. Setting these to zero')
    forces.third = zeros([max(size(forces.second)) max(size(forces.second)) max(size(forces.second))]);
else
    if min(size(forces.third)) < max(params.ham.mode)
        error('The size of the third-order force array is smaller than the mode used for diagonalization. See the documentation')
        
    end
    
end

if ~isfield(forces,'fourth')
    disp('Warning: Fourth-order Force constants not set. Setting these to zero')
    forces.fourth = zeros([max(size(forces.second)) max(size(forces.second)) max(size(forces.second))]);
else
    if min(size(forces.fourth)) < max(params.ham.mode)
        error('The size of the fourth-order force array is smaller than the mode used for diagonalization. See the documentation')
        
    end
end

sizeham = max(params.ham.numBasis.^(2*max(size(params.ham.mode))));

if sizeham > 1E8
    disp(['Warning: The hamiltonian is ' num2str(sqrt(sizeham)) '-by-' num2str(sqrt(sizeham)) '. Make sure you have enough memory available.'])
end