function params = generateHamiltonianParams(params, forces)

%Initialize variables
params.ham.dim = numel(params.ham.mode);
params.ham.truemodes = params.ham.mode;
params.ham.truemodes(params.ham.mode==0)=[];
params.ham.thirdOrderCombs = combn([params.ham.truemodes],3);

%Second-order off-diagonal elements (bilinear coupling)
if min(size(forces.second)) == 1
% The array containing second order forces is a vector (no bilinear
% coupling)
params.ham.twomodeComb = params.ham.truemodes'*[1 1];
forces.second =  diag(forces.second);
else
%Calculate the off-diagonal combinations;
params.ham.twomodeComb = vertcat(params.ham.truemodes'*[1 1], nchoosek(params.ham.truemodes,2));
end

%If the second order force constants are less than 0.5 cm-1 delete the
%entries.
for n = 1:size(params.ham.twomodeComb,1)
    if abs(forces.second(params.ham.twomodeComb(n,1),params.ham.twomodeComb(n,2))) <= 0.5
        params.ham.twomodeComb(n,:) = [0 0];
    end
end
params.ham.twomodeComb(all(params.ham.twomodeComb==0,2),:) = [];

%Third and Fourth order force constants
%If the Force constants are smaller than 0.5 cm-1 do not include in the
%Hamiltonian
for n = 1:size(params.ham.thirdOrderCombs,1)
    if abs(forces.third(params.ham.thirdOrderCombs(n,1),params.ham.thirdOrderCombs(n,2),params.ham.thirdOrderCombs(n,3))) <= 0.5
        params.ham.thirdOrderCombs(n,:) = [0 0 0];
    end
end

params.ham.thirdOrderCombs(all(params.ham.thirdOrderCombs==0,2),:) = [];
params.ham.fourthOrderModes = [];
params.ham.twomode = combn([params.ham.truemodes],2);
longcatvec = [];

for n = 1:size(params.ham.truemodes,2)
    catvec = params.ham.truemodes(n)*ones([1 size(params.ham.twomode,1)])';
    longcatvec = vertcat(longcatvec,catvec);
    params.ham.fourthOrderModes = vertcat(params.ham.fourthOrderModes,params.ham.twomode);
end
params.ham.fourthOrdercombinations = horzcat(params.ham.fourthOrderModes, longcatvec);

for n = 1:size(params.ham.fourthOrdercombinations,1)
    if abs(forces.fourth(params.ham.fourthOrdercombinations(n,1),params.ham.fourthOrdercombinations(n,2),params.ham.fourthOrdercombinations(n,3))) <= 0.5
        params.ham.fourthOrdercombinations(n,:) = [0 0 0];
    end
end

params.ham.fourthOrdercombinations(all(params.ham.fourthOrdercombinations==0,2),:) = [];

